Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(56)

Unified Diff: content/browser/frame_host/frame_tree_node.h

Issue 2764993002: CSP: group policies in didAddContentSecurityPolicy. (Closed)
Patch Set: Nit. Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/frame_host/frame_tree_node.h
diff --git a/content/browser/frame_host/frame_tree_node.h b/content/browser/frame_host/frame_tree_node.h
index 5409f415b3f462626a63ba76b9d46fc9b3914c17..ab75c86bdfe930136930aa7c3a744b421b82c0d4 100644
--- a/content/browser/frame_host/frame_tree_node.h
+++ b/content/browser/frame_host/frame_tree_node.h
@@ -167,9 +167,9 @@ class CONTENT_EXPORT FrameTreeNode {
// Clear any feature policy header associated with the frame.
void ResetFeaturePolicyHeader();
- // Add CSP header to replication state, notify proxies about the update and
- // enforce it on the browser.
- void AddContentSecurityPolicy(const ContentSecurityPolicyHeader& header);
+ // Add CSP headers to replication state, notify proxies about the update.
+ void AddContentSecurityPolicies(
+ const std::vector<ContentSecurityPolicyHeader>& headers);
// Discards previous CSP headers and notifies proxies about the update.
// Typically invoked after committing navigation to a new document (since the
« no previous file with comments | « no previous file | content/browser/frame_host/frame_tree_node.cc » ('j') | content/browser/frame_host/render_frame_host_impl.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698